import { httpApp } from "@/plugins/axiosIndex";
import { object2QueryString } from "@/utils/utils";
import { pickBy } from "lodash-es";
import MD5 from "js-md5";

export async function uploadFile({ file, onProgress }) {
  const form = new FormData();
  form.append("file", file);
  async function blobToArray(blob) {
    return new Promise((resolve) => {
      var reader = new FileReader();
      reader.addEventListener("loadend", function () {
        // reader.result contains the contents of blob as a typed array
        resolve(reader.result);
      });
      reader.readAsArrayBuffer(blob);
    });
  }
  const ab = await blobToArray(file);
  const md5 = MD5(ab);

  return httpApp.post(
    "/api/admin/sys/file/upload?" + object2QueryString({ type: "frontend" }),
    form,
    {
      headers: { "Content-Type": "multipart/form-data", md5: md5 },
      onUploadProgress: function (progressEvent) {
        // console.log(progressEvent);
        let e = {};
        if (progressEvent.total > 0 && progressEvent.loaded) {
          e.percent = (progressEvent.loaded / progressEvent.total) * 100;
        }
        onProgress(e);
      },
    }
  );
}

export function downloadFile({ id = "", type = "" }) {
  const data = pickBy({ id, type }, (v) => v !== "");
  return httpApp.post(
    "/api/admin/sys/file/download?" +
      object2QueryString({ ...data, type: type })
  );
}
